@@ -4,9 +4,9 @@
 
                  Copyright (C) 2000 NetCitadel, LLC
 
-  Author:  Vadim Kurland     vadim@vk.crocodile.org
+  Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWServiceReference.h 35 2008-04-26 19:13:33Z vadim $
+  $Id: FWServiceReference.h 236 2008-12-25 20:36:41Z vadim $
 
 
   This program is free software which we release under the GNU General Public
@@ -45,7 +45,7 @@ class FWServiceReference : public FWReference
     DECLARE_FWOBJECT_SUBTYPE(FWServiceReference);
 
     FWServiceReference();
-    FWServiceReference(const FWObject *root,bool prepopulate);
+    FWServiceReference(const FWObjectDatabase *root,bool prepopulate);
 
     void setPointer(Service *o);
     void setPointer(ServiceGroup *o);
